# GADMA ![](http://jb.gg/badges/research-flat-square.svg)

[![Docs](https://readthedocs.org/projects/gadma/badge/?version=latest)](https://gadma.readthedocs.io/en/latest/?badge=latest) [![Build Status](https://travis-ci.com/ctlab/GADMA.svg?branch=master)](https://travis-ci.com/ctlab/GADMA) [![codecov](https://codecov.io/gh/ctlab/GADMA/branch/master/graph/badge.svg?token=F303UDEWDJ)](undefined)

Welcome to GADMA v2!

GADMA implements methods for automatic inferring joint demographic history of multiple populations from the genetic data.

GADMA is based on two open source packages: the ∂a∂i developed by Ryan Gutenkunst [<https://bitbucket.org/gutenkunstlab/dadi/>] and the *moments* developed by Simon Gravel [<https://bitbucket.org/simongravel/moments/>].

In contrast, GADMA is a command-line tool. It presents a series of launches of the genetic algorithm and infer demographic history from Allele Frequency Spectrum of multiple populations (up to three).

GADMA is implemented by Ekaterina Noskova (ekaterina.e.noskova@gmail.com)

**GADMA is now of version 2!**

### Documentation

Full documentation including installation instructions, usage, examples and API are available [here](https://gadma.readthedocs.io).

### Contributors

* Ekaterina Noskova

* Vladimir Ulyantsev

* Pavel Dobrynin

## Getting help

Please don't be afraid to contact me for different problems and offers via email ekaterina.e.noskova@gmail.com. I will be glad to answer all questions. 

Also you are always welcome to [create an issue](https://github.com/ctlab/GADMA/issues) on GitHub page of GADMA project with your question.

## Citation

If you use GADMA in your research please cite:

Ekaterina Noskova, Vladimir Ulyantsev, Klaus-Peter Koepfli, Stephen J O’Brien, Pavel Dobrynin, GADMA: Genetic algorithm for inferring demographic history of multiple populations from allele frequency spectrum data, *GigaScience*, Volume 9, Issue 3, March 2020, giaa005, <https://doi.org/10.1093/gigascience/giaa005>
